import React from 'react';
import { ControlContainer, TooltipProvider, Tooltip, TooltipTrigger, Button, TooltipContent } from '../../components';
import { Popover, PopoverTrigger, PopoverContent } from '../../components/layout/Popover';
import { useAppDispatch } from '../../data-access';
import { clearQB } from '../../data-access/store/querybuilderSlice';
import { QueryMLDialog } from './querysidepanel/QueryMLDialog';
import { QuerySettings } from './querysidepanel/QuerySettings';

export type QueryBuilderToggleSettings = 'settings' | 'ml' | 'logic' | 'relatedNodes' | undefined;

export type QueryBuilderNavProps = {
  toggleSettings: QueryBuilderToggleSettings;
  onFitView: () => void;
  onApplyLayout: () => void;
  onRunQuery: () => void;
  onScreenshot: () => void;
  onLogic: () => void;
};

export const QueryBuilderNav = (props: QueryBuilderNavProps) => {
  const dispatch = useAppDispatch();

  /**
   * Clears all nodes in the graph.
   */
  function clearAllNodes() {
    dispatch(clearQB());
  }

  return (
    <div className="sticky shrink-0 top-0 flex items-stretch justify-between h-7 bg-secondary-100 border-b border-secondary-200 max-w-full">
      <div className="flex items-center">
        <h1 className="text-xs font-semibold text-secondary-600 px-2 truncate">Query builder</h1>
      </div>
      <div className="sticky right-0 px-0.5 ml-auto items-center flex truncate">
        <ControlContainer>
          <TooltipProvider delayDuration={0}>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--baseline-fullscreen]"
                  onClick={props.onFitView}
                />
              </TooltipTrigger>
              <TooltipContent>
                <p>Fit to screen</p>
              </TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--baseline-delete]"
                  onClick={() => clearAllNodes()}
                />
              </TooltipTrigger>
              <TooltipContent>
                <p>Clear query panel</p>
              </TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--baseline-camera-alt]"
                  onClick={props.onScreenshot}
                />
              </TooltipTrigger>
              <TooltipContent>
                <p>Capture screen</p>
              </TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--baseline-import-export]"
                  onClick={props.onApplyLayout}
                />
              </TooltipTrigger>
              <TooltipContent>
                <p>Layouts</p>
              </TooltipContent>
            </Tooltip>
            <Popover>
              <PopoverTrigger>
                <Tooltip>
                  <TooltipTrigger>
                    <Button
                      variantType="secondary"
                      variant="ghost"
                      size="xs"
                      iconComponent="icon-[ic--baseline-settings]"
                      className="query-settings"
                    />
                  </TooltipTrigger>
                  <TooltipContent>
                    <p>Query builder settings</p>
                  </TooltipContent>
                </Tooltip>
              </PopoverTrigger>
              <PopoverContent>
                <QuerySettings />
              </PopoverContent>
            </Popover>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--baseline-cached]"
                  onClick={props.onRunQuery}
                />
              </TooltipTrigger>
              <TooltipContent>
                <p>Rerun query</p>
              </TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger asChild>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--baseline-difference]"
                  onClick={props.onLogic}
                />
              </TooltipTrigger>
              <TooltipContent disabled={props.toggleSettings === 'logic'}>
                <p>Logic settings</p>
              </TooltipContent>
            </Tooltip>
            <Popover>
              <PopoverTrigger>
                <Tooltip>
                  <TooltipTrigger>
                    <Button variantType="secondary" variant="ghost" size="xs" iconComponent="icon-[ic--baseline-lightbulb]" />
                  </TooltipTrigger>
                  <TooltipContent disabled={props.toggleSettings === 'ml'}>
                    <p>Machine learning</p>
                  </TooltipContent>
                </Tooltip>
              </PopoverTrigger>
              <PopoverContent>
                <QueryMLDialog />
              </PopoverContent>
            </Popover>
            {/* <Tooltip>
            <TooltipTrigger>
              <Button
                variantType="secondary"
                variant="ghost"
                size="xs"
                iconComponent="icon-[ic--baseline-drive-file-move]"
                onClick={() => onAddSchemaToQueryBuilder()}
              />
            </TooltipTrigger>
            <TooltipContent>
              <p>Query All Data</p>
            </TooltipContent>
          </Tooltip> */}
          </TooltipProvider>
        </ControlContainer>
      </div>
    </div>
  );
};
